@@ -2,15 +2,15 @@ import tartes
 from pylab import *
 
 
-ssa = [20,15,10]         # in m^2/kg
-density = [200,250,300]  # in kg/m^3
-thickness = [0.01,0.10,1000] # thickness of each layer in meter
+ssa = [20,15,10]
+density = [200,250,300]
+depth = [0.01,0.10,1000] # depth of each layer in meter
 wavelengths = arange(300,2500,10)*1e-9 # from 300 to 2500 nm
 
-albedo_3layers = tartes.albedo(wavelengths,ssa,density,thickness)
+albedo_3layers = tartes.albedo(wavelengths,ssa,density,depth)
 
-ssa = 20         # in m^2/kg
-density = 300    # in kg/m^3
+ssa = 20  
+density = 300
 albedo_semiinfinite = tartes.albedo(wavelengths,ssa,density)
 
 
