@@ -3,8 +3,8 @@ import tartes.impurities
 from pylab import *
 
 
-ssa = 20      # in m^2/kg
-density = 300 # in kg/m^3
+ssa = 20      #
+density = 300 #
 
 wavelengths = arange(300,1000,10)*1e-9 # from 300 to 2500nm
 
@@ -15,7 +15,7 @@ albedo_pure = tartes.albedo(wavelengths,ssa,density)
 albedo_soot = tartes.albedo(wavelengths,ssa,density,impurities=50e-9)
 
 
-# 200ng/g of Hulis.
+# 200ng/g of Hulis. Soot is the default impurity type
 albedo_hulis = tartes.albedo(wavelengths,ssa,density,
                              impurities=200e-9,
                              impurities_type=tartes.impurities.HULIS)
