@@ -3,18 +3,18 @@ import tartes.impurities
 from pylab import *
 
 
-ssa = [40,30,20] # in m^2/kg
-density = [300,300,300] # in kg/m^3
-thickness = [0.02,0.05,1000] # in m
+ssa = [40,30,20]      #
+density = [300,300,300]
+depth = [0.02,0.05,1000] 
 
 wavelengths = arange(300,1000,10)*1e-9 # from 300 to 2500nm
 
 # pure snow
-albedo_pure = tartes.albedo(wavelengths,ssa,density,thickness)
+albedo_pure = tartes.albedo(wavelengths,ssa,density,depth)
 
 # with a profile of soot
 albedo_soot = tartes.albedo(wavelengths,
-                            ssa,density,thickness,
+                            ssa,density,depth,
                             impurities=[10e-9, 50e-9, 0])
 
 # A profile of mixture soot+Hulis
@@ -24,7 +24,7 @@ impurities_content= [
     [0, 10e-9]  # soot and HULIS in the last layer
 ]
 
-albedo_mixture = tartes.albedo(wavelengths,ssa,density,thickness,
+albedo_mixture = tartes.albedo(wavelengths,ssa,density,depth,
                                impurities=impurities_content,
                                impurities_type=[tartes.impurities.Soot,
                                                 tartes.impurities.HULIS])
