@@ -46,11 +46,11 @@ default_B0 = 1.6 # Based on Libois et al. 2014
 default_g0 = 0.86 # deduce for the b value derived from Gallet et al. 2009 SSA versus albedo measurements.
 
 
-def albedo(wavelength, SSA, density, thickness=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
+def albedo(wavelength, SSA, density, depth=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
        impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0,theta_inc=0):
 
     """
-compute the spectral albedo of a snowpack specified by the profiles of SSA and density using TARTES. The underlying interface has an albedo specified by soilalbedo (0.0 by default). For semi-infinite snowpack, use thickness = None (the default value).
+compute the spectral albedo of a snowpack specified by the profiles of SSA and density using TARTES. The underlying interface has an albedo specified by soilalbedo (0.0 by default). For semi-infinite snowpack, use depth = None (the default value).
 
 :param wavelength: wavelength (m)
 :type wavelength: array    
@@ -58,8 +58,8 @@ compute the spectral albedo of a snowpack specified by the profiles of SSA and d
 :type SSA: array
 :param density: density (kg/m^3)
 :type density: array
-:param thickness: thickness of each layer (m). By default is None meaning a semi-infinite medium.
-:type thickness: array
+:param depth: depth of each layer (m). By default is None meaning a semi-infinite medium.
+:type depth: array
 :param g0: asymmetry parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 0.86. g0 can be scalar (constant in the snowpack) or an array like the SSA.
 :type g0: array or scalar
 :param B0: absorption enhancement parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 1.6, taken from Libois et al. 2014. B0 can be scalar (constant in the snowpack) or an array like the SSA.
@@ -84,7 +84,7 @@ compute the spectral albedo of a snowpack specified by the profiles of SSA and d
 
     mudir = cos(theta_inc*pi/180)
 
-    albedo = tartes(wavelength,SSA,density,thickness,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=dir_frac,mudir=mudir)
+    albedo = tartes(wavelength,SSA,density,depth,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=dir_frac,mudir=mudir)
     if albedo.shape==(1,):
         return float(albedo)
     else:
@@ -93,7 +93,7 @@ compute the spectral albedo of a snowpack specified by the profiles of SSA and d
 
 
 
-def absorption_profile(wavelength, SSA, density, thickness=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
+def absorption_profile(wavelength, SSA, density, depth=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
                impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0.0,totflux=1.0,theta_inc=0):
 
     """
@@ -105,8 +105,8 @@ compute the energy absorbed in every layer and in the soil. The parameters are t
 :type SSA: array
 :param density: density (kg/m^3)
 :type density: array
-:param thickness: thickness of each layer (m). By default is None meaning a semi-infinite medium.
-:type thickness: array
+:param depth: depth of each layer (m). By default is None meaning a semi-infinite medium.
+:type depth: array
 :param g0: asymmetry parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 0.86. g0 can be scalar (constant in the snowpack) or an array like the SSA.
 :type g0: array or scalar
 :param B0: absorption enhancement parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 1.6, taken from Libois et al. 2014. B0 can be scalar (constant in the snowpack) or an array like the SSA.
@@ -133,13 +133,13 @@ compute the energy absorbed in every layer and in the soil. The parameters are t
 
     mudir = cos(theta_inc*pi/180)
 
-    albedo,absorption = tartes(wavelength,SSA,density,thickness,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=dir_frac,totflux=totflux,mudir=mudir,compute_absorption=True)
+    albedo,absorption = tartes(wavelength,SSA,density,depth,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=0.0,totflux=1.0,mudir=mudir, compute_absorption=True)
 
-    return insert(cumsum(thickness),0,0),absorption
+    return insert(cumsum(depth),0,0),absorption
 
 
 
-def irradiance_profiles(wavelength, z, SSA, density, thickness=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
+def irradiance_profiles(wavelength, z, SSA, density, depth=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
                impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0,totflux=1.0,theta_inc=0):
 
     """compute the upwelling and downwelling irradiance at every depth z. The parameters are the same as for the absorption_profile function plus the depths z. If both the albedo and the absorption_profile is needed, a direct call to the tartes function is recommended.
@@ -152,8 +152,8 @@ def irradiance_profiles(wavelength, z, SSA, density, thickness=None,g0=default_g
 :type SSA: array
 :param density: density (kg/m^3)
 :type density: array
-:param thickness: thickness of each layer (m). By default is None meaning a semi-infinite medium.
-:type thickness: array
+:param depth: depth of each layer (m). By default is None meaning a semi-infinite medium.
+:type depth: array
 :param g0: asymmetry parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 0.86. g0 can be scalar (constant in the snowpack) or an array like the SSA.
 :type g0: array or scalar
 :param B0: absorption enhancement parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 1.6, taken from Libois et al. 2014. B0 can be scalar (constant in the snowpack) or an array like the SSA.
@@ -174,64 +174,17 @@ def irradiance_profiles(wavelength, z, SSA, density, thickness=None,g0=default_g
 :type totflux: array
 :param theta_inc: incident angle of direct light (degree, 0 means nadir)
 :type theta_inc: scalar
-:returns: a tupple with downwelling and upwelling irradiance profiles. The return type is an array with the first dimension for the wavelength and the second for the layers. If the wavelength argument is a scalar, the first dimension is squeezed.
+:returns: a tupple with downwelling and upwelling irradiance profiles. The return type is an array with the first dimension for the wavelength and the second for the layers + an extra value for the soil. If the wavelength argument is a scalar, the first dimension is squeezed.
     """
 
     mudir = cos(theta_inc*pi/180)
 
-    albedo,down,up = tartes(wavelength,SSA,density,thickness,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=dir_frac,totflux=totflux,mudir=mudir,compute_irradiance_profiles=True,z=z)
+    albedo,down,up = tartes(wavelength,SSA,density,depth,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=0.0,totflux=1.0,mudir=mudir, compute_irradiance_profiles=True,z=z)
 
     return down.squeeze(),up.squeeze()
 
 
 
-
-def actinic_profile(wavelength, z, SSA, density, thickness=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,
-               impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0,totflux=1.0,theta_inc=0):
-
-    """compute the actinic flux at every depth z. The parameters are the same as for the irradiance profile.
-
-:param wavelength: wavelength (m)
-:type wavelength: array
-:param z: depths at which the irradiance are calculated (m)
-:type z: array
-:param SSA: surface specific area (m^2/kg) for each layer
-:type SSA: array
-:param density: density (kg/m^3)
-:type density: array
-:param thickness: thickness of each layer (m). By default is None meaning a semi-infinite medium.
-:type thickness: array
-:param g0: asymmetry parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 0.86. g0 can be scalar (constant in the snowpack) or an array like the SSA.
-:type g0: array or scalar
-:param B0: absorption enhancement parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 1.6, taken from Libois et al. 2014. B0 can be scalar (constant in the snowpack) or an array like the SSA.
-:type B0: array or scalar
-:param y0: Value of y of snow grains at nr=1.3 (no unit).  See Eqs 72 and 75 in the "science" doc for the default value. y0 can be scalar (same for all layers) or an array like the SSA.
-:type y0: array or scalar
-:param W0: Value of W of snow grains at nr=1.3 (no unit). See Eqs 72 and 75 in the "science" doc for the default value. W0 can be a scalar (same for all layers) or an array like the SSA.
-:type W0: array or scalar
-:param impurities: impurities concentration (kg/kg) in each layer. It is either a constant or an array with size equal to the number of layers. The array is 1-d if only one type of impurities is used and 2-d otherwise.
-:type impurities: array or scalar
-:param impurities_type: specify the type of impurity. By defaut it is "soot". Otherwise it should be a class (or an instance) defining the density and the imaginary part of the refractive index like the Soot class (see tartes.impurities for possible choices and to add new impurities types). It can also be a list of classes if several impurities type are present in the snowpack. In this case, the impurities parameter must be a 2-d array.
-:type impurities_type: object or list of object
-:param soilalbedo: spectral albedo of the underlying (no unit). soilalbedo can be a scalar or an array like wavelength.
-:type soilalbedo: scalar or array
-:param dir_frac: fraction of directional flux over the total flux (the default is dir_frac = 0 meaning 100% diffuse incident flux) at every wavelength
-:type dir_frac: array
-:param totflux: total spectral incident flux (direct+diffuse) (W/m^2)
-:type totflux: array
-:param theta_inc: incident angle of direct light (degree, 0 means nadir)
-:type theta_inc: scalar
-:returns: the actinic flux profile. The return type is an array with the first dimension for the wavelength and the second for the layers. If the wavelength argument is a scalar, the first dimension is squeezed.
-    """
-
-    mudir = cos(theta_inc*pi/180)
-
-    albedo,actinic = tartes(wavelength,SSA,density,thickness,g0=g0,B0=B0,y0=y0,impurities=impurities,impurities_type=impurities_type,soilalbedo=soilalbedo,dir_frac=dir_frac,totflux=totflux,mudir=mudir,compute_actinic_profile=True,z=z)
-
-    return actinic.squeeze()
-
-
-
 #######################################################################################################
 #
 # The following functions are the core of TARTES but are as convenient to use as the previous one.
@@ -371,7 +324,7 @@ def infinite_medium_optical_parameters(ssalb,g):
     return albedo,kestar
 
 
-def taustar_vector(SSA,density,thickness,ssalb,g,kestar):
+def taustar_vector(SSA,density,depth,ssalb,g,kestar):
     """compute the taustar and dtaustar of the snowpack, the optical depth of each layer and cumulated optical depth
     see doc Section 1.2, 1.8, 2.4
 
@@ -379,8 +332,10 @@ def taustar_vector(SSA,density,thickness,ssalb,g,kestar):
     :type SSA: array
     :param density: vertical profile of density (kg/m^3)
     :type density: array
-    :param thickness: thickness of each layers (m)
-    :type thickness: array
+    :param depth: thickness of each layers (m)
+    :type depth: array
+    :param depth: thickness of each layers (m)
+    :type depth: array
     :param ssalb: single scattering albedo (no unit)
     :type ssalb: array
     :param g: asymmetry factor (no unit)
@@ -391,7 +346,7 @@ def taustar_vector(SSA,density,thickness,ssalb,g,kestar):
     :returns: optical depth of each layer (unbounded + bounded) and cumulated optical depth (no unit)
 """
     sigext = density*SSA/2                    
-    dtaustar_ub = sigext*thickness[newaxis,:]*(1-ssalb*g**2)    # delta-Eddington variable change    
+    dtaustar_ub = sigext*depth[newaxis,:]*(1-ssalb*g**2)    # delta-Eddington variable change    
     
     maximum_optical_depth_per_layer=200    
     dtaustar=minimum(dtaustar_ub,maximum_optical_depth_per_layer/kestar)
@@ -735,8 +690,8 @@ def soa(x,i):
         return x
 
 
-def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0.0,totflux=1.0,mudir=0,compute_absorption=False,compute_irradiance_profiles=False,compute_actinic_profile=False,z=None):
-    """compute spectral albedo, and optionally the absorption in each layer and in the soil, the downwelling and upwelling irradiance profiles and the actinic flux from the physical properties of the snowpack and the incidence flux conditions.
+def tartes(wavelength,SSA,density,depth=None,g0=default_g0,B0=default_B0,y0=0.728,W0=0.0611,impurities=0,impurities_type=Soot,soilalbedo=0.0,dir_frac=0.0,totflux=1.0,mudir=0,compute_absorption=False,compute_irradiance_profiles=False,z=None):
+    """compute spectral albedo, and optionally the absorption in each layer and in the soil, and the irradiance profiles from the physical properties of the snowpack and the incidence flux conditions.
 
 :param wavelength: wavelength (m)
 :type wavelength: array or scalar        
@@ -744,8 +699,8 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
 :type SSA: array or scalar
 :param density: snow density (kg/m^3) 
 :type density: array or scalar
-:param thickness: thickness of the layers (m)
-:type thickness: array or scalar
+:param depth: thickness of the layers (m)
+:type depth: array or scalar
 :param g0: asymmetry parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 0.86. g0 can be scalar (constant in the snowpack) or an array like the SSA.
 :type g0: array or scalar
 :param B0: absorption enhancement parameter of snow grains at nr=1.3 and at non absorbing wavelengths (no unit). The default value is 1.6, taken from Libois et al. 2014. B0 can be scalar (constant in the snowpack) or an array like the SSA.
@@ -768,25 +723,23 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
 :type mudir: scalar
 :param compute_absorption: if True compute the absorption profile and the absorption in the soil
 :type compute_absorption: boolean
-:param compute_irradiance_profiles: if True compute the profiles of up- and down-welling irradiance at depths z
-:type compute_actinic_profile: boolean
-:param compute_actinic_profile: if True compute the profile of actinic flux at depths z
+:param compute_irradiance_profiles: if True compute the profiles of up- and down-welling irradiance
 :type compute_irradiance_profiles: boolean
 :param z: depth at which the irradiance is calculed. It is used only if compute_irradiance_profile is activated.
 :type z: array
 
-:returns: spectral albedo, and optionaly absorption by layer (note the bottom layer correspond to the absorption by the soil) and optionnaly the profile of irradiance: downwelling, upwelling
+:returns: spectral albedo, and optionaly absorption by layer (note the bottom layer correspond to the absorption by the soil) and optionnaly the profile of irradiance as a tuple: downwelling, upwelling
 
 """
 
     #the diffuse incident flux is treated as direct flux at incident angle 53°
     mudiff=cos(53./180*pi)
     
-    # convert SSA, density and thickness to array if necessary
+    # convert SSA, density and depth to array if necessary
     SSA = atleast_1d(SSA)
     density = atleast_1d(density)
-    if thickness is None: thickness=1e9 # chosing a value should never been a problem...
-    thickness = atleast_1d(thickness)
+    if depth is None: depth=1e9 # chosing a value should never been a problem...
+    depth = atleast_1d(depth)
 
     wavelength = atleast_1d(wavelength)
     N=len(wavelength)    
@@ -796,14 +749,10 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
     if compute_absorption:
         energyprofile=zeros( (N,nlyr+1) )
 
-    if compute_irradiance_profiles or compute_actinic_profile:
+    if compute_irradiance_profiles:
         nz = len(z)
-        if compute_irradiance_profiles:
-            down_irr_profile = zeros( (N,nz) )
-            up_irr_profile = zeros( (N,nz) )
-        if compute_actinic_profile:
-            actinic_profile = zeros( (N,nz) )
-        
+        X = zeros( (N,nz) )    
+        Y = zeros( (N,nz) ) 
         depth_total=zeros(nlyr+1)    
         depth_total[1:]=cumsum(depth)
         nearest_layer=searchsorted(depth_total,z,side="right") #number of the layer (1,2...)
@@ -821,14 +770,18 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
     for n in range(nlyr):
         ssalb[:,n],g[:,n] = single_scattering_optical_parameters(wavelength,
                                                                  refrac_index,
-                                                                 SSA[n],density[n],
+                                                                 SSA[n],
+                                                                 density[n],
                                                                  soa(impurities,n),
                                                                  impurities_type,
-                                                                 soa(g0,n),soa(y0,n),soa(W0,n),soa(B0,n))
+                                                                 soa(g0,n),
+                                                                 soa(y0,n),
+                                                                 soa(W0,n),
+                                                                 soa(B0,n))
         alb[:,n],kestar[:,n] = infinite_medium_optical_parameters(ssalb[:,n],g[:,n])
 
     # 2 computation on every wavelength and layer of the optical depth
-    dtaustar_ub,dtaustar,taustar = taustar_vector(SSA,density,thickness,ssalb,g,kestar)
+    dtaustar_ub,dtaustar,taustar = taustar_vector(SSA,density,depth,ssalb,g,kestar)
 
     nlyrmax = estimate_effective_layer_number(wavelength,kestar,dtaustar) # use to limit the computation at depth for highly absorbing wavelength. Seems to be inefficient in Python for a normal ~40 layers snowpack and 10nm resolution.
 
@@ -862,7 +815,7 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
             Gpdiff_i=0
             Gmdiff_i=0
 
-        # If the snowpack was truncated, the last layer thickness is increased and a high albedo is used for the soil
+        # If the snowpack was truncated, the last layer depth is increased and a high albedo is used for the soil
         if neff<nlyr:
             dtaustar[i,neff]=30./kestar[i,neff]
             soilalbedo_i=1
@@ -905,7 +858,7 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
             energyprofile[i,-1]=dirflux_i/mudir*soil_absorption(solutions_dir,kestar_i,dtaustar_i,taustar_i,Gmdir_i,mudir,soilalbedo_i) + \
                 diffflux_i/mudiff*soil_absorption(solutions_diff,kestar_i,dtaustar_i,taustar_i,Gmdiff_i,mudiff,soilalbedo_i)
 
-        if compute_irradiance_profiles or compute_actinic_profile:
+        if compute_irradiance_profiles:
             # compute the profile of downward intensity
             if solutions_dir is not None:
                 A_dir,B_dir,C_dir,D_dir=solutions_dir
@@ -922,41 +875,22 @@ def tartes(wavelength,SSA,density,thickness=None,g0=default_g0,B0=default_B0,y0=
                 expm = exp(-kestar_i[m-1]*dtaustar_z)
                 expp = exp(kestar_i[m-1]*dtaustar_z)
 
-                if compute_irradiance_profiles:
-                    if dirflux_i>0:
-                        down_irr_profile[i,nz0] = dirflux_i/mudir*(A_dir[m-1]*expm+ \
-                                                                   B_dir[m-1]*expp+ \
-                                                                   (Gmdir_i[m-1]+mudir)*exp(-taustar_z/mudir))
-                        up_irr_profile[i,nz0] = dirflux_i/mudir*(C_dir[m-1]*expm+ \
-                                                                 D_dir[m-1]*expp+ \
-                                                                 Gpdir_i[m-1]*exp(-taustar_z/mudir))
-                    if diffflux_i>0:
-                        down_irr_profile[i,nz0] += diffflux_i/mudiff*(A_diff[m-1]*expm+ \
-                                                                      B_diff[m-1]*expp+ \
-                                                                      (Gmdiff_i[m-1]+mudiff)*exp(-taustar_z/mudiff))
-                        up_irr_profile[i,nz0] += diffflux_i/mudiff*(C_diff[m-1]*expm+ \
-                                                                    D_diff[m-1]*expp+ \
-                                                                    Gpdiff_i[m-1]*exp(-taustar_z/mudiff))
-                if compute_actinic_profile:
-                    if dirflux_i>0:
-                        actinic_profile[i,nz0] = dirflux_i/mudir*( 2*(A_dir[m-1]+C_dir[m-1])*expm+ \
-                                                           2*(B_dir[m-1]+D_dir[m-1])*expp+ \
-                                                           (Gmdir_i[m-1]+mudir)*exp(-taustar_z/mudir))
-                    if diffflux_i>0:
-                        actinic_profile[i,nz0] += diffflux_i/mudiff*( 2*(A_diff[m-1]+C_diff[m-1])*expm+ \
-                                                           2*(B_diff[m-1]+D_diff[m-1])*expp+ \
-                                                           (Gmdiff_i[m-1]+mudiff)*exp(-taustar_z/mudiff))
+                if dirflux_i>0:
+                    X[i,nz0] = dirflux_i/mudir*(A_dir[m-1]*expm+B_dir[m-1]*expp+(Gmdir_i[m-1]+mudir)*exp(-taustar_z/mudir))
+                    Y[i,nz0] = dirflux_i/mudir*(C_dir[m-1]*expm+D_dir[m-1]*expp+Gpdir_i[m-1]*exp(-taustar_z/mudir))
+                if diffflux_i>0:
+                    X[i,nz0] += diffflux_i/mudiff*(A_diff[m-1]*expm+B_diff[m-1]*expp+(Gmdiff_i[m-1]+mudiff)*exp(-taustar_z/mudiff))
+                    Y[i,nz0] += diffflux_i/mudiff*(C_diff[m-1]*expm+D_diff[m-1]*expp+Gpdiff_i[m-1]*exp(-taustar_z/mudiff))
 
-    if not compute_absorption and not compute_irradiance_profiles and not compute_actinic_profile:
+
+    if not compute_absorption and not compute_irradiance_profiles:
         return albedo.squeeze()
     else:
         ret = [albedo.squeeze()]
         if compute_absorption:
             ret.append(energyprofile.squeeze())
         if compute_irradiance_profiles:
-            ret.append(down_irr_profile)
-            ret.append(up_irr_profile)
-        if compute_actinic_profile:
-            ret.append(actinic_profile)
+            ret.append(X)
+            ret.append(Y)
         return tuple(ret)
 
